==> geopsypack-src-3.3.6.tar.gz: geopsypack-src-3.3.6/gpviewmax/src/HistogramsWidget.h <==
/***************************************************************************
**
**  This file is part of gpviewmax.
**
**  gpviewmax is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  gpviewmax is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2018-07-16
**  Copyright: 2018-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef HISTOGRAMSWIDGET_H
#define HISTOGRAMSWIDGET_H

#include <SciFigs.h>
#include <QGpCoreWave.h>

#include "Samples.h"
#include "Reader.h"
//#include "ui_HistogramsWidget.h"

class ModeWidgets;

class HistogramsWidget : public GraphicSheetMenu //public QWidget, private Ui::HistogramsWidget
{
  Q_OBJECT
public:
  HistogramsWidget(QWidget * parent=nullptr);
  ~HistogramsWidget();

  void setNormalize(bool n) {_normalize=n;}
  void setSamples(const Samples& s, const Reader& param);
  bool splitModes(const Samples& s, const Reader& param);
  void setHistogramComments(QString cmt);
  void exportPlot(const ExportOptions& o);
protected:
  void closeEvent(QCloseEvent * e);
private:
  bool _normalize;
  QList<ModeWidgets *> _modes;
};

#endif // HISTOGRAMSWIDGET_H

==> geopsypack-src-3.4.0.tar.gz: geopsypack-src-3.4.0/gpviewmax/src/HistogramsWidget.h <==
/***************************************************************************
**
**  This file is part of gpviewmax.
**
**  gpviewmax is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  gpviewmax is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2018-07-16
**  Copyright: 2018-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef HISTOGRAMSWIDGET_H
#define HISTOGRAMSWIDGET_H

#include <SciFigs.h>
#include <QGpCoreWave.h>

#include "Samples.h"
#include "Reader.h"
//#include "ui_HistogramsWidget.h"

class ModeWidgets;

class HistogramsWidget : public GraphicSheetMenu //public QWidget, private Ui::HistogramsWidget
{
  Q_OBJECT
public:
  HistogramsWidget(QWidget * parent=nullptr);
  ~HistogramsWidget();

  void setNormalize(bool n) {_normalize=n;}
  void setSamples(const Samples& s, const Reader& param);
  bool splitModes(const Samples& s, const Reader& param);
  void setHistogramComments(QString cmt);
  void exportPlot(const ExportOptions& o);
protected:
  void closeEvent(QCloseEvent * e);
  bool splitModesFromCurves(const Samples& s, const Reader& param);
  void splitModesFromEllSign(const Samples& s, const Reader& param);
private:
  bool _normalize;
  QList<ModeWidgets *> _modes;
};

#endif // HISTOGRAMSWIDGET_H
